-- Daily Global Check
-- by Jadya
-- EU-Well of Eternity

local addonTitle, addonTable = ...
local L = addonTable.L

local constructors = DailyGlobalCheck.Constructors
local options = DailyGlobalCheck.OptFunctions
local addontitle = "|TInterface\\icons\\INV_Sigil_Freya:16 |t|cff00AAFFDaily Global Check|r"
local frameoffsetY = -60

------ DGC Base Options ------
local function createOptionsFrame(p)

 local of = CreateFrame("Frame", "DGCOOptionsFrame", p)
 of:SetAllPoints()
 
 local chkmap_child 
 local chkcounter = 0

 local function CreateCheckbox(opt, text)
 
  local function OnOptionChanged(opt)
   if opt == "show_mapicons" or opt == "show_mapicons_all" then
    addonTable.forcemapupdate()
   end
  end

  local f = constructors:checkboxtemplate(of, p:GetWidth() - 40, text)
  
  table.insert(of.checkboxes, f)
  f:SetPoint("TOPLEFT", of, "TOPLEFT", 10, frameoffsetY + -20 * chkcounter)
  
  f:SetScript("OnClick", function(self)
    if opt == "minimap_icon" then
      DailyGlobalCheck_Options["minimap_icon"].hide = not self:GetChecked()
 	 addonTable.ldbicon:Refresh("DailyGlobalCheck_broker", DailyGlobalCheck_broker, DailyGlobalCheck_Options["minimap_icon"])
    else
     DailyGlobalCheck_Options[opt] = self:GetChecked()
	 if opt == "show_mapicons" then
      chkmap_child:SetEnabled(DailyGlobalCheck_Options[opt])
	 end
	 OnOptionChanged(opt)
	 DailyGlobalCheck:Refresh()
    end
  end)
 
  if opt == "minimap_icon" then
   f:SetChecked(DailyGlobalCheck_Options["minimap_icon"] and not DailyGlobalCheck_Options["minimap_icon"].hide or false)
  else
   f:SetChecked(DailyGlobalCheck_Options[opt])
  end
  chkcounter = chkcounter + 1
  return f
 end

 of.checkboxes = {}
 CreateCheckbox("minimap_icon",L["opt_minimap"])
 chkcounter = chkcounter + 1
 CreateCheckbox("show_questtype", L["opt_questtype"])
 CreateCheckbox("show_prefix", L["opt_prefix"])
 CreateCheckbox("show_zone", L["opt_zonename"])
 CreateCheckbox("show_suffix", L["opt_suffix"])
 CreateCheckbox("show_coordinates", L["opt_coords"])
 CreateCheckbox("hide_completed", L["opt_hidecompleted"])
 chkcounter = chkcounter + 2
 CreateCheckbox("show_questlogbtn", L["opt_showquestbtn"])
 chkcounter = chkcounter + 2
 CreateCheckbox("show_mapicons", L["opt_map"])
 chkcounter = chkcounter + 1
 chkmap_child = CreateCheckbox("show_mapicons_all", L["opt_map_all"])
 chkmap_child:SetEnabled(DailyGlobalCheck_Options["show_mapicons"])
 return of
end

------ Plugin Options ------
local opt_plugin_title, lastselected

-- widgets handling
local widgets_pool = {}
local function getwidget(t)
 local found
 for k,v in pairs(widgets_pool) do
  if v.t == t then
   found = k
   break
  end
 end
 
 if found then
  local f = widgets_pool[found]
  table.remove(widgets_pool, found)
  table.insert(DGCOPluginOptionsFrame.widgets, f)
  return f
 elseif t == "Checkbox" or t == "Radiobutton" then
  local f = constructors:checkboxtemplate(DGCOPluginOptionsFrame, DGCOptionsFrame:GetWidth() - 40, "")
  table.insert(DGCOPluginOptionsFrame.widgets, f)
  f.t = t
  return f
 end
end
--

local function updatepluginframe()
 local list = DailyGlobalCheck:GetSelectedList()
 local of = DGCOPluginOptionsFrame

 if not of or list == lastselected then return end
 
  for _,v in pairs(of.widgets) do
   v:Hide()
   table.insert(widgets_pool, v)
  end
  wipe(of.widgets)
 
 if not list or not list["Options"] then
  opt_plugin_title:SetText(L["plugin_opt_title"].."\n\n"..L["plugin_opt_none"])
 else
  opt_plugin_title:SetText(L["plugin_opt_title"])

  -- widgets creation
  if not DailyGlobalCheck_PluginData[list["Title"]] then DailyGlobalCheck_PluginData[list["Title"]] = {} end
  local svar = DailyGlobalCheck_PluginData[list["Title"]]
  if not svar.options then svar.options = {} end

  for i,v in pairs(list["Options"]) do
   local t, text, refresh, flags = unpack(v)
   local f = getwidget(t)
   f.tag = i
   f:SetPoint("TOPLEFT", of, "TOPLEFT", 10, frameoffsetY + -20 * i)
   
   if t == "Checkbox" then
    f.title:SetText(text)
    f:SetChecked(svar.options[i])
	
    f:SetScript("OnClick", function(self)

     if not svar.options then svar.options = {} end
	 svar.options[self.tag] = f:GetChecked()
	 
	 if list.OnOptionChanged then
	  list.OnOptionChanged(self.tag)
	 end
	 
	 if refresh then
	  DailyGlobalCheck:Refresh()
     end
    end)
   elseif t == "Radiobutton" then
    local category = flags[1] or 0
	
    f.title:SetText(text)
    f:SetChecked(svar.options[i])
	f.category = category
	
    f:SetScript("OnClick", function(self)

     if not svar.options then svar.options = {} end
	 
	 for wi,ww in pairs(of.widgets) do
	  if ww.category == category and ww ~= f then
	   ww:SetChecked(false)
	   svar.options[wi] = false
	  end
	 end

	 svar.options[i] = true
	 f:SetChecked(true)
	
	 if refresh then
	  DailyGlobalCheck:Refresh()
     end
    end)
   end
   f:Show()
  end
  -- 
 end
 lastselected = list
end

local function createPluginFrame(p)

 local of = CreateFrame("Frame", "DGCOPluginOptionsFrame", p)
 of:SetAllPoints()
 
 local t = of:CreateFontString(nil, "OVERLAY", "GameTooltipText")
 t:SetPoint("TOPLEFT", of, "TOPLEFT", 10, -50)
 opt_plugin_title = t
 of.widgets = {}
 updatepluginframe()
 
 t:SetWordWrap(true)
 t:SetWidth(p:GetWidth() - 20)
 return of
end

function options:OnDraw()
 updatepluginframe()
end


local frames_backdrop  = { bgFile = "Interface\\Buttons\\GreyscaleRamp64", 
                           edgeFile = "Interface\\Buttons\\WHITE8X8", 
						   edgeSize = 1
						   }

----------------
function options:CreateOptionsFrame(parent)
 local f = CreateFrame("Frame","DGCOptionsFrame",parent)
 f:SetFrameStrata("HIGH")
 f:SetBackdrop(frames_backdrop)
 f:SetBackdropColor(0.07,0.07,0.07,0.9)
 f:SetBackdropBorderColor(0.1,0.1,0.1,0.9)
 f:SetPoint("LEFT", parent, "RIGHT")
 f:SetHeight(390)
 f:SetWidth(200)

 local function onmouseup(self)
  for _,v in pairs(f.buttons) do
   v:SetBackdropColor(0,0,0,0.9)
   v.panel:Hide()
  end
  self:SetBackdropColor(0,1,0,0.9)
  self.panel:Show()
 end
 
 f.buttons = {}

 -- Options Frame
 f.Options = createOptionsFrame(f)
 
 local btn = constructors:largebuttontemplate(f, GAMEOPTIONS_MENU, "")
 btn:SetBackdropColor(0,1,0,0.9)
 btn:SetPoint("TOPLEFT")
 btn.panel = f.Options
 btn:SetScript("OnMouseUp", onmouseup)
 f.buttons.btnopt = btn

-- Plugin Options Frame
 f.Plugin = createPluginFrame(f)
 f.Plugin:Hide()
 
 btn = constructors:largebuttontemplate(f, "Plugin", "")
 btn:SetBackdropColor(0,0,0,0.9)
 btn:SetPoint("LEFT", f.buttons.btnopt, "RIGHT")
 btn.panel = f.Plugin
 btn:SetScript("OnMouseUp", onmouseup)
 f.buttons.btnplugin = btn

 f:Hide()
 return f
end

--[[ Blizzard Interface Panel --

-- main panel
local function generateMainOptions(p)
 local grp = constructors:Groupbox(p, nil, 150, 150, "General")
 
 local f = constructors:checkboxtemplate(grp, 140, "Old style")
 f:SetPoint("TOPLEFT", grp, "TOPLEFT", 5, -5)
end

DailyGlobalCheck.BlizzOptionsPanel = CreateFrame("Frame", "DGC_BlizzOptionsPanel", UIParent)
local f = DailyGlobalCheck.BlizzOptionsPanel
f:Hide()
f.name = "Daily Global Check"
f.generate = generateMainOptions
f:SetScript("OnShow", f.generate)
InterfaceOptions_AddCategory(f)
]]


--[[ UI Panel

local function generateUIOptions()

end

f = CreateFrame("Frame", "DailyGlobalCheck_BlizzOptionsPanel2", UIParent)
f.name   = "UI"
f.parent = "Daily Global Check"
f:SetScript("OnShow", generateUIOptions)
InterfaceOptions_AddCategory(f)
]]